@@ -1,22 +1,9 @@
 /*
-   This file is part of the KDE Baloo project.
- * Copyright (C) 2015  Vishesh Handa <vhanda@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    This file is part of the KDE Baloo project.
+    SPDX-FileCopyrightText: 2015 Vishesh Handa <vhanda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "postingdb.h"
 #include "singledbtest.h"
@@ -45,7 +32,7 @@ private Q_SLOTS:
         db.put("fire", {1, 8, 9});
         db.put("fore", {2, 3, 5});
 
-        PostingIterator* it = db.iter("fir");
+        std::unique_ptr<PostingIterator> it{db.iter("fir")};
         QVERIFY(it);
 
         QVector<quint64> result = {1, 3, 5};
@@ -63,7 +50,7 @@ private Q_SLOTS:
         db.put("fire", {1, 8, 9});
         db.put("fore", {2, 3, 5});
 
-        PostingIterator* it = db.prefixIter("fi");
+        std::unique_ptr<PostingIterator> it{db.prefixIter("fi")};
         QVERIFY(it);
 
         QVector<quint64> result = {1, 3, 5, 8, 9};
@@ -82,7 +69,7 @@ private Q_SLOTS:
         db.put("fore", {2, 3, 5});
         db.put("zib", {4, 5, 6});
 
-        PostingIterator* it = db.regexpIter(QRegularExpression(QStringLiteral(".re")), QByteArray("f"));
+        std::unique_ptr<PostingIterator> it{db.regexpIter(QRegularExpression(QStringLiteral(".re")), QByteArray("f"))};
         QVERIFY(it);
 
         QVector<quint64> result = {1, 2, 3, 5, 8};
@@ -92,7 +79,7 @@ private Q_SLOTS:
         }
 
         // Non existing
-        it = db.regexpIter(QRegularExpression(QStringLiteral("dub")), QByteArray("f"));
+        it.reset(db.regexpIter(QRegularExpression(QStringLiteral("dub")), QByteArray("f")));
         QVERIFY(it == nullptr);
     }
 
@@ -103,20 +90,48 @@ private Q_SLOTS:
         db.put("R1", {1, 3, 5, 7});
         db.put("R2", {1, 8});
         db.put("R3", {2, 3, 5});
+        db.put("R10", {10, 12});
+        // X20- is the internal encoding for KFileMetaData::Property::LineCount
+        db.put("X20-90", {1, 2});
+        db.put("X20-1000", {10, 11});
 
-        PostingIterator* it = db.compIter("R", "2", PostingDB::GreaterEqual);
+        std::unique_ptr<PostingIterator> it{db.compIter("R", 2, PostingDB::GreaterEqual)};
         QVERIFY(it);
 
-        QVector<quint64> result = {1, 2, 3, 5, 8};
-        for (quint64 val : result) {
+        QVector<quint64> result = {1, 2, 3, 5, 8, 10, 12};
+        for (quint64 val : std::as_const(result)) {
             QCOMPARE(it->next(), static_cast<quint64>(val));
             QCOMPARE(it->docId(), static_cast<quint64>(val));
         }
 
-        it = db.compIter("R", "2", PostingDB::LessEqual);
+        it.reset(db.compIter("R", 2, PostingDB::LessEqual));
         QVERIFY(it);
         result = {1, 3, 5, 7, 8};
-        for (quint64 val : result) {
+        for (quint64 val : std::as_const(result)) {
+            QCOMPARE(it->next(), static_cast<quint64>(val));
+            QCOMPARE(it->docId(), static_cast<quint64>(val));
+        }
+
+        it.reset(db.compIter("R", 10, PostingDB::GreaterEqual));
+        QVERIFY(it);
+        result = {10, 12};
+        for (quint64 val : std::as_const(result)) {
+            QCOMPARE(it->next(), static_cast<quint64>(val));
+            QCOMPARE(it->docId(), static_cast<quint64>(val));
+        }
+
+        it.reset(db.compIter("X20-", 80, PostingDB::GreaterEqual));
+        QVERIFY(it);
+        result = {1, 2, 10, 11};
+        for (quint64 val : std::as_const(result)) {
+            QCOMPARE(it->next(), static_cast<quint64>(val));
+            QCOMPARE(it->docId(), static_cast<quint64>(val));
+        }
+
+        it.reset(db.compIter("X20-", 100, PostingDB::GreaterEqual));
+        QVERIFY(it);
+        result = {10, 11};
+        for (quint64 val : std::as_const(result)) {
             QCOMPARE(it->next(), static_cast<quint64>(val));
             QCOMPARE(it->docId(), static_cast<quint64>(val));
         }
