@@ -1,36 +1,20 @@
 /*
- * This file is part of the KDE Baloo Project
- * Copyright (C) 2015  Pinak Ahuja <pinak.ahuja@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE Baloo Project
+    SPDX-FileCopyrightText: 2015 Pinak Ahuja <pinak.ahuja@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "monitor.h"
 
 #include "database.h"
 #include "transaction.h"
 #include "global.h"
+#include "config.h"
 
 #include <QDBusConnection>
-#include <QDBusMessage>
 #include <QDBusConnectionInterface>
 #include <QDebug>
-#include <QStandardPaths>
 #include <QDBusServiceWatcher>
 #include <QProcess>
 
@@ -43,7 +27,6 @@ Monitor::Monitor(QObject *parent)
     , m_filePath(QStringLiteral("Idle"))
     , m_scheduler(nullptr)
     , m_fileindexer(nullptr)
-    , m_filesIndexed(0)
     , m_remainingTime(QStringLiteral("Estimating"))
 {
     m_scheduler = new org::kde::baloo::scheduler(QStringLiteral("org.kde.baloo"),
@@ -60,33 +43,37 @@ Monitor::Monitor(QObject *parent)
     connect(m_scheduler, &org::kde::baloo::scheduler::stateChanged,
             this, &Monitor::slotIndexerStateChanged);
 
+    QDBusServiceWatcher* balooWatcher = new QDBusServiceWatcher(m_scheduler->service(),
+                                                            m_bus,
+                                                            QDBusServiceWatcher::WatchForOwnerChange,
+                                                            this);
+    connect(balooWatcher, &QDBusServiceWatcher::serviceRegistered, this, &Monitor::balooStarted);
+    connect(balooWatcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() {
+        m_balooRunning = false;
+        m_indexerState = Baloo::Unavailable;
+        Q_EMIT balooStateChanged();
+        Q_EMIT indexerStateChanged();
+    });
+
     if (m_scheduler->isValid()) {
         // baloo is already running
-        balooStarted(m_scheduler->service());
-
-    } else {
-        m_balooRunning = false;
-        QDBusServiceWatcher* balooWatcher = new QDBusServiceWatcher(m_scheduler->service(),
-                                                                m_bus,
-                                                                QDBusServiceWatcher::WatchForRegistration,
-                                                                this);
-        connect(balooWatcher, &QDBusServiceWatcher::serviceRegistered, this, &Monitor::balooStarted);
+        balooStarted();
     }
 }
 
 void Monitor::newFile(const QString& filePath)
 {
+    m_filePath = filePath;
     if (m_totalFiles == 0) {
         fetchTotalFiles();
     }
-    m_filePath = filePath;
-    if (++m_filesIndexed == m_totalFiles) {
-        m_filePath = QStringLiteral("Done");
-    }
+    ++m_filesIndexed;
     Q_EMIT newFileIndexed();
 
-    if (m_filesIndexed % 100 == 0) {
+    auto now = QDeadlineTimer::current();
+    if (now > m_remainingTimeTimer) {
         updateRemainingTime();
+        m_remainingTimeTimer = now + 1000;
     }
 }
 
@@ -97,8 +84,6 @@ QString Monitor::suspendState() const
 
 void Monitor::toggleSuspendState()
 {
-    Q_ASSERT(m_scheduler != nullptr);
-
     if (m_indexerState == Baloo::Suspended) {
         m_scheduler->resume();
     } else {
@@ -106,20 +91,12 @@ void Monitor::toggleSuspendState()
     }
 }
 
-void Monitor::balooStarted(const QString& service)
+void Monitor::balooStarted()
 {
-    Q_ASSERT(service == QStringLiteral("org.kde.baloo"));
-
     m_balooRunning = true;
     m_fileindexer->registerMonitor();
 
     slotIndexerStateChanged(m_scheduler->state());
-    // qDebug() << "fetched suspend state";
-    fetchTotalFiles();
-    if (m_indexerState == Baloo::ContentIndexing) {
-        m_filePath = m_fileindexer->currentFile();
-        updateRemainingTime();
-    }
     Q_EMIT balooStateChanged();
 }
 
@@ -131,19 +108,24 @@ void Monitor::fetchTotalFiles()
         m_totalFiles = tr.size();
         m_filesIndexed = tr.size() - tr.phaseOneSize();
         Q_EMIT totalFilesChanged();
+        Q_EMIT newFileIndexed();
     }
 }
 
 void Monitor::startBaloo()
 {
-    const QString exe = QStandardPaths::findExecutable(QStringLiteral("baloo_file"));
-    QProcess::startDetached(exe);
+    const QString exe = QStringLiteral(KDE_INSTALL_FULL_LIBEXECDIR_KF "/baloo_file");
+    QProcess::startDetached(exe, QStringList());
 }
 
 void Monitor::updateRemainingTime()
 {
-    m_remainingTime = KFormat().formatSpelloutDuration(m_scheduler->getRemainingTime());
-    Q_EMIT remainingTimeChanged();
+    auto remainingTime = m_scheduler->getRemainingTime();
+    if ((remainingTime != m_remainingTimeSeconds) && (remainingTime > 0)) {
+        m_remainingTime = KFormat().formatSpelloutDuration(remainingTime);
+        m_remainingTimeSeconds = remainingTime;
+        Q_EMIT remainingTimeChanged();
+    }
 }
 
 void Monitor::slotIndexerStateChanged(int state)
@@ -152,8 +134,12 @@ void Monitor::slotIndexerStateChanged(int state)
 
     if (m_indexerState != newState) {
         m_indexerState = newState;
-        Q_EMIT indexerStateChanged();
         fetchTotalFiles();
+        if (m_indexerState != Baloo::ContentIndexing) {
+            m_filePath = QString();
+        }
+        Q_EMIT indexerStateChanged();
     }
 }
 
+#include "moc_monitor.cpp"
